==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/sq.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'sq', {
	button: {
		title: 'Rekuizitat e Pullës',
		text: 'Teskti (Vlera)',
		type: 'LLoji',
		typeBtn: 'Buton',
		typeSbm: 'Dërgo',
		typeRst: 'Rikthe'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Rekuizitat e Kutizë Përzgjedhëse',
		radioTitle: 'Rekuizitat e Pullës',
		value: 'Vlera',
		selected: 'Përzgjedhur'
	},
	form: {
		title: 'Rekuizitat e Formës',
		menu: 'Rekuizitat e Formës',
		action: 'Veprim',
		method: 'Metoda',
		encoding: 'Kodimi'
	},
	hidden: {
		title: 'Rekuizitat e Fushës së Fshehur',
		name: 'Emër',
		value: 'Vlera'
	},
	select: {
		title: 'Rekuizitat e Fushës së Përzgjedhur',
		selectInfo: 'Përzgjidh Informacionin',
		opAvail: 'Opsionet e Mundshme',
		value: 'Vlera',
		size: 'Madhësia',
		lines: 'rreshtat',
		chkMulti: 'Lejo përzgjidhje të shumëfishta',
		opText: 'Teksti',
		opValue: 'Vlera',
		btnAdd: 'Vendos',
		btnModify: 'Ndrysho',
		btnUp: 'Sipër',
		btnDown: 'Poshtë',
		btnSetValue: 'Bëje si vlerë të përzgjedhur',
		btnDelete: 'Grise'
	},
	textarea: {
		title: 'Rekuzitat e Fushës së Tekstit',
		cols: 'Kolonat',
		rows: 'Rreshtat'
	},
	textfield: {
		title: 'Rekuizitat e Fushës së Tekstit',
		name: 'Emër',
		value: 'Vlera',
		charWidth: 'Gjerësia e Karakterit',
		maxChars: 'Numri maksimal i karaktereve',
		type: 'LLoji',
		typeText: 'Teksti',
		typePass: 'Fjalëkalimi',
		typeEmail: 'Posta Elektronike',
		typeSearch: 'Kërko',
		typeTel: 'Numri i Telefonit',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/sq.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'sq', {
	button: {
		title: 'Rekuizitat e Pullës',
		text: 'Teskti (Vlera)',
		type: 'LLoji',
		typeBtn: 'Buton',
		typeSbm: 'Dërgo',
		typeRst: 'Rikthe'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Rekuizitat e Kutizë Përzgjedhëse',
		radioTitle: 'Rekuizitat e Pullës',
		value: 'Vlera',
		selected: 'Përzgjedhur',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Rekuizitat e Formës',
		menu: 'Rekuizitat e Formës',
		action: 'Veprim',
		method: 'Metoda',
		encoding: 'Kodimi'
	},
	hidden: {
		title: 'Rekuizitat e Fushës së Fshehur',
		name: 'Emër',
		value: 'Vlera'
	},
	select: {
		title: 'Rekuizitat e Fushës së Përzgjedhur',
		selectInfo: 'Përzgjidh Informacionin',
		opAvail: 'Opsionet e Mundshme',
		value: 'Vlera',
		size: 'Madhësia',
		lines: 'rreshtat',
		chkMulti: 'Lejo përzgjidhje të shumëfishta',
		required: 'Required', // MISSING
		opText: 'Teksti',
		opValue: 'Vlera',
		btnAdd: 'Vendos',
		btnModify: 'Ndrysho',
		btnUp: 'Sipër',
		btnDown: 'Poshtë',
		btnSetValue: 'Bëje si vlerë të përzgjedhur',
		btnDelete: 'Grise'
	},
	textarea: {
		title: 'Rekuzitat e Fushës së Tekstit',
		cols: 'Kolonat',
		rows: 'Rreshtat'
	},
	textfield: {
		title: 'Rekuizitat e Fushës së Tekstit',
		name: 'Emër',
		value: 'Vlera',
		charWidth: 'Gjerësia e Karakterit',
		maxChars: 'Numri maksimal i karaktereve',
		required: 'Required', // MISSING
		type: 'LLoji',
		typeText: 'Teksti',
		typePass: 'Fjalëkalimi',
		typeEmail: 'Posta Elektronike',
		typeSearch: 'Kërko',
		typeTel: 'Numri i Telefonit',
		typeUrl: 'URL'
	}
} );
